Class: Aws::Signer::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Signer::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-signer/client.rb,
sig/client.rbs
Overview
An API client for Signer. To construct a client, you need to configure a :region and :credentials.
client = Aws::Signer::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AddProfilePermissionResponseSuccess, _DescribeSigningJobResponseSuccess, _GetRevocationStatusResponseSuccess, _GetSigningPlatformResponseSuccess, _GetSigningProfileResponseSuccess, _ListProfilePermissionsResponseSuccess, _ListSigningJobsResponseSuccess, _ListSigningPlatformsResponseSuccess, _ListSigningProfilesResponseSuccess, _ListTagsForResourceResponseSuccess, _PutSigningProfileResponseSuccess, _RemoveProfilePermissionResponseSuccess, _SignPayloadResponseSuccess, _StartSigningJobResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_profile_permission(params = {}) ⇒ Types::AddProfilePermissionResponse
Adds cross-account permissions to a signing profile.
-
#cancel_signing_profile(params = {}) ⇒ Struct
Changes the state of an
ACTIVEsigning profile toCANCELED. -
#describe_signing_job(params = {}) ⇒ Types::DescribeSigningJobResponse
Returns information about a specific code signing job.
-
#get_revocation_status(params = {}) ⇒ Types::GetRevocationStatusResponse
Retrieves the revocation status of one or more of the signing profile, signing job, and signing certificate.
-
#get_signing_platform(params = {}) ⇒ Types::GetSigningPlatformResponse
Returns information on a specific signing platform.
-
#get_signing_profile(params = {}) ⇒ Types::GetSigningProfileResponse
Returns information on a specific signing profile.
-
#list_profile_permissions(params = {}) ⇒ Types::ListProfilePermissionsResponse
Lists the cross-account permissions associated with a signing profile.
-
#list_signing_jobs(params = {}) ⇒ Types::ListSigningJobsResponse
Lists all your signing jobs.
-
#list_signing_platforms(params = {}) ⇒ Types::ListSigningPlatformsResponse
Lists all signing platforms available in AWS Signer that match the request parameters.
-
#list_signing_profiles(params = {}) ⇒ Types::ListSigningProfilesResponse
Lists all available signing profiles in your AWS account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags associated with a signing profile resource.
-
#put_signing_profile(params = {}) ⇒ Types::PutSigningProfileResponse
Creates a signing profile.
-
#remove_profile_permission(params = {}) ⇒ Types::RemoveProfilePermissionResponse
Removes cross-account permissions from a signing profile.
-
#revoke_signature(params = {}) ⇒ Struct
Changes the state of a signing job to
REVOKED. -
#revoke_signing_profile(params = {}) ⇒ Struct
Changes the state of a signing profile to
REVOKED. -
#sign_payload(params = {}) ⇒ Types::SignPayloadResponse
Signs a binary payload and returns a signature envelope.
-
#start_signing_job(params = {}) ⇒ Types::StartSigningJobResponse
Initiates a signing job to be performed on the code provided.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a signing profile.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a signing profile.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-signer/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1688 1689 1690 |
# File 'lib/aws-sdk-signer/client.rb', line 1688 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1691 1692 1693 |
# File 'lib/aws-sdk-signer/client.rb', line 1691 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_profile_permission(params = {}) ⇒ Types::AddProfilePermissionResponse
Adds cross-account permissions to a signing profile.
86 |
# File 'sig/client.rbs', line 86
def add_profile_permission: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 |
# File 'lib/aws-sdk-signer/client.rb', line 1548 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Signer') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-signer' context[:gem_version] = '1.87.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_signing_profile(params = {}) ⇒ Struct
Changes the state of an ACTIVE signing profile to CANCELED. A
canceled profile is still viewable with the ListSigningProfiles
operation, but it cannot perform new signing jobs. See Data
Retention for more information on scheduled deletion of a canceled
signing profile.
97 |
# File 'sig/client.rbs', line 97
def cancel_signing_profile: (
|
#describe_signing_job(params = {}) ⇒ Types::DescribeSigningJobResponse
Returns information about a specific code signing job. You specify the
job by using the jobId value that is returned by the StartSigningJob
operation.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* successful_signing_job
125 |
# File 'sig/client.rbs', line 125
def describe_signing_job: (
|
#get_revocation_status(params = {}) ⇒ Types::GetRevocationStatusResponse
Retrieves the revocation status of one or more of the signing profile, signing job, and signing certificate.
135 |
# File 'sig/client.rbs', line 135
def get_revocation_status: (
|
#get_signing_platform(params = {}) ⇒ Types::GetSigningPlatformResponse
Returns information on a specific signing platform.
157 |
# File 'sig/client.rbs', line 157
def get_signing_platform: (
|
#get_signing_profile(params = {}) ⇒ Types::GetSigningProfileResponse
Returns information on a specific signing profile.
180 |
# File 'sig/client.rbs', line 180
def get_signing_profile: (
|
#list_profile_permissions(params = {}) ⇒ Types::ListProfilePermissionsResponse
Lists the cross-account permissions associated with a signing profile.
194 |
# File 'sig/client.rbs', line 194
def list_profile_permissions: (
|
#list_signing_jobs(params = {}) ⇒ Types::ListSigningJobsResponse
Lists all your signing jobs. You can use the maxResults parameter to
limit the number of signing jobs that are returned in the response. If
additional jobs remain to be listed, AWS Signer returns a nextToken
value. Use this value in subsequent calls to ListSigningJobs to
fetch the remaining values. You can continue calling ListSigningJobs
with your maxResults parameter and with new values that Signer
returns in the nextToken parameter until all of your signing jobs
have been returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
206 |
# File 'sig/client.rbs', line 206
def list_signing_jobs: (
|
#list_signing_platforms(params = {}) ⇒ Types::ListSigningPlatformsResponse
Lists all signing platforms available in AWS Signer that match the
request parameters. If additional jobs remain to be listed, Signer
returns a nextToken value. Use this value in subsequent calls to
ListSigningJobs to fetch the remaining values. You can continue
calling ListSigningJobs with your maxResults parameter and with
new values that Signer returns in the nextToken parameter until all
of your signing jobs have been returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
225 |
# File 'sig/client.rbs', line 225
def list_signing_platforms: (
|
#list_signing_profiles(params = {}) ⇒ Types::ListSigningProfilesResponse
Lists all available signing profiles in your AWS account. Returns only
profiles with an ACTIVE status unless the includeCanceled request
field is set to true. If additional jobs remain to be listed, AWS
Signer returns a nextToken value. Use this value in subsequent calls
to ListSigningJobs to fetch the remaining values. You can continue
calling ListSigningJobs with your maxResults parameter and with
new values that Signer returns in the nextToken parameter until all
of your signing jobs have been returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
240 |
# File 'sig/client.rbs', line 240
def list_signing_profiles: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags associated with a signing profile resource.
254 |
# File 'sig/client.rbs', line 254
def list_tags_for_resource: (
|
#put_signing_profile(params = {}) ⇒ Types::PutSigningProfileResponse
Creates a signing profile. A signing profile is a code-signing template that can be used to carry out a pre-defined signing job.
266 |
# File 'sig/client.rbs', line 266
def put_signing_profile: (
|
#remove_profile_permission(params = {}) ⇒ Types::RemoveProfilePermissionResponse
Removes cross-account permissions from a signing profile.
293 |
# File 'sig/client.rbs', line 293
def remove_profile_permission: (
|
#revoke_signature(params = {}) ⇒ Struct
Changes the state of a signing job to REVOKED. This indicates that
the signature is no longer valid.
301 |
# File 'sig/client.rbs', line 301
def revoke_signature: (
|
#revoke_signing_profile(params = {}) ⇒ Struct
Changes the state of a signing profile to REVOKED. This indicates
that signatures generated using the signing profile after an effective
start date are no longer valid. A revoked profile is still viewable
with the ListSigningProfiles operation, but it cannot perform new
signing jobs. See Data Retention for more information on
scheduled deletion of a revoked signing profile.
309 |
# File 'sig/client.rbs', line 309
def revoke_signing_profile: (
|
#sign_payload(params = {}) ⇒ Types::SignPayloadResponse
Signs a binary payload and returns a signature envelope.
325 |
# File 'sig/client.rbs', line 325
def sign_payload: (
|
#start_signing_job(params = {}) ⇒ Types::StartSigningJobResponse
Initiates a signing job to be performed on the code provided. Signing
jobs are viewable by the ListSigningJobs operation. Note the
following requirements:
-
You must create an Amazon S3 source bucket. For more information, see Creating a Bucket in the Amazon S3 Getting Started Guide.
-
Your S3 source bucket must be version enabled.
-
You must create an S3 destination bucket. AWS Signer uses your S3 destination bucket to write your signed code.
-
You specify the name of the source and destination buckets when calling the
StartSigningJoboperation. -
You must ensure the S3 buckets are from the same Region as the signing profile. Cross-Region signing isn't supported.
-
You must also specify a request token that identifies your request to Signer.
You can call the DescribeSigningJob and the ListSigningJobs actions
after you call StartSigningJob.
For a Java example that shows how to use this action, see StartSigningJob.
339 |
# File 'sig/client.rbs', line 339
def start_signing_job: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a signing profile. Tags are labels that you can use to identify and organize your AWS resources. Each tag consists of a key and an optional value. To specify the signing profile, use its Amazon Resource Name (ARN). To specify the tag, use a key-value pair.
363 |
# File 'sig/client.rbs', line 363
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a signing profile. To remove the tags, specify a list of tag keys.
373 |
# File 'sig/client.rbs', line 373
def untag_resource: (
|
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| successful_signing_job | #describe_signing_job | 20 | 25 |
380 |
# File 'sig/client.rbs', line 380
def wait_until: (:successful_signing_job waiter_name,
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1662 1663 1664 |
# File 'lib/aws-sdk-signer/client.rb', line 1662 def waiter_names waiters.keys end |