Class: Aws::Signer::Types::ListSigningProfilesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Signer::Types::ListSigningProfilesResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-signer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
Value for specifying the next set of paginated results to return.
-
#profiles ⇒ Array<Types::SigningProfile>
A list of profiles that are available in the AWS account.
Instance Attribute Details
#next_token ⇒ String
Value for specifying the next set of paginated results to return.
802 803 804 805 806 807 |
# File 'lib/aws-sdk-signer/types.rb', line 802 class ListSigningProfilesResponse < Struct.new( :profiles, :next_token) SENSITIVE = [] include Aws::Structure end |
#profiles ⇒ Array<Types::SigningProfile>
A list of profiles that are available in the AWS account. This includes profiles with the status of CANCELED if the includeCanceled parameter is set to true.
802 803 804 805 806 807 |
# File 'lib/aws-sdk-signer/types.rb', line 802 class ListSigningProfilesResponse < Struct.new( :profiles, :next_token) SENSITIVE = [] include Aws::Structure end |